@@ -65,14 +65,14 @@ class Add2DOption : public InlineOptions
         : m_kalgebra(c)
         {}
         
-        virtual QString id() const { return QStringLiteral("add2d"); }
-        virtual bool matchesExpression(const Analitza::Expression& exp, const Analitza::ExpressionType& /*functype*/) const {
+        QString id() const Q_DECL_OVERRIDE { return QStringLiteral("add2d"); }
+        bool matchesExpression(const Analitza::Expression& exp) const Q_DECL_OVERRIDE {
             return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim2D).canDraw();
         }
 
-        virtual QString caption() const { return i18n("Plot 2D"); }
+        QString caption() const Q_DECL_OVERRIDE { return i18n("Plot 2D"); }
 
-        virtual void triggerOption(const Analitza::Expression& exp) { m_kalgebra->add2D(exp); }
+        void triggerOption(const Analitza::Expression& exp) Q_DECL_OVERRIDE { m_kalgebra->add2D(exp); }
     
     private:
         KAlgebra* m_kalgebra;
@@ -85,15 +85,15 @@ class Add3DOption : public InlineOptions
         : m_kalgebra(c)
         {}
         
-        virtual QString id() const { return QStringLiteral("add3d"); }
-        virtual bool matchesExpression(const Analitza::Expression& exp, const Analitza::ExpressionType& /*functype*/) const
+        QString id() const Q_DECL_OVERRIDE { return QStringLiteral("add3d"); }
+        bool matchesExpression(const Analitza::Expression& exp) const Q_DECL_OVERRIDE
         {
             return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D).canDraw();
         }
 
-        virtual QString caption() const { return i18n("Plot 3D"); }
+        QString caption() const Q_DECL_OVERRIDE { return i18n("Plot 3D"); }
 
-        virtual void triggerOption(const Analitza::Expression& exp) { m_kalgebra->add3D(exp); }
+        void triggerOption(const Analitza::Expression& exp) Q_DECL_OVERRIDE { m_kalgebra->add3D(exp); }
     
     private:
         KAlgebra* m_kalgebra;
@@ -308,7 +308,7 @@ KAlgebra::KAlgebra(QWidget *parent)
     t_menu = menuBar()->addMenu(i18n("3D &Graph"));
     QAction* t_actions[5];
     t_menu->addAction(KStandardAction::save(this, SLOT(save3DGraph()), this));
-    t_menu->addAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("&Reset View"), m_graph3d, [this]() { m_graph3d->resetView(); });
+    t_menu->addAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("&Reset View"), m_graph3d, [this]() { m_graph3d->resetViewport(); });
     t_menu->addSeparator();
     t_actions[2] = t_menu->addAction(i18n("Dots"), this, SLOT(set_dots()));
     t_actions[3] = t_menu->addAction(i18n("Lines"), this, SLOT(set_lines()));
@@ -559,25 +559,9 @@ void KAlgebra::set_solid()
 
 void KAlgebra::save3DGraph()
 {
-    QString path = QFileDialog::getSaveFileName(this, QString(), QString(), i18n("PNG File (*.png);;PDF Document(*.pdf);;X3D Document (*.x3d);;STL Document (*.stl)"));
+    QString path = QFileDialog::getSaveFileName(this, QString(), QString(), m_graph3d->filters().join(";;"));
     if(!path.isEmpty()) {
-        if(path.endsWith(QLatin1String(".x3d")) || path.endsWith(QLatin1String(".stl"))) {
-            m_graph3d->exportSurfaces(path);
-        } else if(path.endsWith(QLatin1String(".pdf"))) {
-            auto px = m_graph3d->grabFramebuffer();
-            QPrinter printer;
-            printer.setOutputFormat(QPrinter::PdfFormat);
-            printer.setOutputFileName(path);
-            printer.setPaperSize(px.size(), QPrinter::DevicePixel);
-            printer.setPageMargins(0,0,0,0, QPrinter::DevicePixel);
-            QPainter painter;
-            painter.begin(&printer);
-            painter.drawImage(QPoint(0,0), px);
-            painter.end();
-        } else {
-            auto px = m_graph3d->grabFramebuffer();
-            px.save(path);
-        }
+        m_graph3d->save(QUrl::fromLocalFile(path));
     }
 }
 
@@ -667,12 +651,12 @@ void KAlgebra::updateInformation()
 
 void KAlgebra::consoleCalculate()
 {
-    c_results->setMode(ConsoleHtml::Calculation);
+    c_results->setMode(ConsoleModel::Calculation);
 }
 
 void KAlgebra::consoleEvaluate()
 {
-    c_results->setMode(ConsoleHtml::Evaluation);
+    c_results->setMode(ConsoleModel::Evaluation);
 }
 
 void KAlgebra::valueChanged()
